@@ -1,3 +1,4 @@
+import random
 from enum import IntEnum
 from io import BytesIO
 from typing import Any, Dict, Optional, overload
@@ -76,11 +77,20 @@ class SauceEndpoint(BaseEndpoint):
     async def request(
         self, *, file: UploadFileIO, params: Dict[str, Any]
     ) -> Dict[str, Any]:
-        params.update({"api_key": SauceConstants.API_KEY, "output_type": 2})
         response = await self.client.post(
-            url=self._join(self.base, "search.php", params), files={"file": file}
+            url=self._join(
+                self.base,
+                "search.php",
+                params={
+                    **params,
+                    "api_key": random.choice(SauceConstants.API_KEY),
+                    "output_type": 2,
+                },
+            ),
+            files={"file": file},
         )
-        response.raise_for_status()
+        if response.status_code >= 500:
+            response.raise_for_status()
         return response.json()
 
     @overload
