@@ -1,19 +1,25 @@
 import asyncio
-from typing import NoReturn
+from secrets import compare_digest
+from typing import List, NoReturn
 from urllib.parse import ParseResult
 
 import sentry_sdk
-from fastapi import FastAPI, Request, Response
+from fastapi import Depends, FastAPI, Request, Response
+from fastapi.security import HTTPBasic, HTTPBasicCredentials
 from fastapi.staticfiles import StaticFiles
+from pydantic import BaseModel
+from sentry_sdk.integrations.logging import LoggingIntegration
+
 from hibiapi import __version__
 from hibiapi.utils.config import Config
+from hibiapi.utils.exceptions import ClientSideException
 from hibiapi.utils.log import logger
 from hibiapi.utils.temp import TempFile
-from sentry_sdk.integrations.logging import LoggingIntegration
 
 from .routes import router as ImplRouter
 
-DESCRIPTION = """
+DESCRIPTION = (
+    """
 **A program that implements easy-to-use APIs for a variety of commonly used sites**
 
 - *Documents*:
@@ -22,11 +28,9 @@ DESCRIPTION = """
 
 Project: [mixmoe/HibiAPI](https://github.com/mixmoe/HibiAPI)
 
-![](https://img.shields.io/github/stars/mixmoe/HibiAPI?color=brightgreen&logo=github&style=for-the-badge)
 """
-
-if slogan := Config["content"]["slogan"].as_str().strip():
-    DESCRIPTION += "\n" + slogan
+    + Config["content"]["slogan"].as_str().strip()
+).strip()
 
 
 if Config["log"]["sentry"]["enabled"].as_bool():
@@ -38,6 +42,34 @@ if Config["log"]["sentry"]["enabled"].as_bool():
     )
 
 
+class AuthorizationModel(BaseModel):
+    username: str
+    password: str
+
+
+AUTHORIZATION_ENABLED = Config["authorization"]["enabled"].as_bool()
+AUTHORIZATION_ALLOWED = {
+    user.username: user.password
+    for user in Config["authorization"]["allowed"].get(List[AuthorizationModel])
+}
+
+security = HTTPBasic()
+
+
+def basic_authorization_depend(credentials: HTTPBasicCredentials = Depends(security)):
+    # NOTE: We use `compare_digest` to avoid timing attacks.
+    # Ref: https://fastapi.tiangolo.com/advanced/security/http-basic-auth/
+    if (credentials.username in AUTHORIZATION_ALLOWED) and compare_digest(
+        credentials.password, AUTHORIZATION_ALLOWED[credentials.username]
+    ):
+        return credentials.username, credentials.password
+    raise ClientSideException(
+        f"Invalid credentials for user {credentials.username!r}",
+        status_code=401,
+        headers={"WWW-Authenticate": "Basic"},
+    )
+
+
 app = FastAPI(
     debug=Config["debug"].as_bool(),
     title="HibiAPI",
@@ -46,7 +78,13 @@ app = FastAPI(
     docs_url="/docs/test",
     redoc_url="/docs",
 )
-app.include_router(ImplRouter, prefix="/api")
+app.include_router(
+    ImplRouter,
+    prefix="/api",
+    dependencies=(
+        [Depends(basic_authorization_depend)] if AUTHORIZATION_ENABLED else []
+    ),
+)
 app.mount(
     "/temp",
     StaticFiles(directory=str(TempFile.path), check_dir=False),
