@@ -13,18 +13,23 @@ from hibiapi.api.pixiv import (
     RankingType,
     SearchDurationType,
     SearchModeType,
+    SearchNovelModeType,
     SearchSortType,
 )
 from hibiapi.utils.log import logger
 from hibiapi.utils.routing import SlashRouter, exclude_params
 
+if not PixivConstants.CONFIG["account"]["token"].get():
+    logger.warning("Pixiv API token is not set, pixiv endpoint will be unavailable.")
+    PixivConstants.CONFIG["enabled"].set(False)
+
 __mount__, __config__ = "pixiv", PixivConstants.CONFIG
 router = SlashRouter(tags=["Pixiv"])
 
 PixivAPIRoot = PixivAPI()
 
 
-async def requestClient():
+async def request_client():
     async with PixivAPIRoot.net as client:
         yield PixivEndpoints(client)
 
@@ -47,17 +52,17 @@ async def login():
 
 
 @router.get("/", summary="Pixiv API 兼容实现")
-async def matchAll(
+async def _match_all(
     request: Request,
     type: EndpointsType = EndpointsType.illust,
-    endpoint: PixivEndpoints = Depends(requestClient),
+    endpoint: PixivEndpoints = Depends(request_client),
 ):
     func: Callable[..., Coroutine] = getattr(endpoint, type)
     return await func(**exclude_params(func, request.query_params))
 
 
 @router.get(EndpointsType.illust)
-async def illust(id: int, endpoint: PixivEndpoints = Depends(requestClient)):
+async def illust(id: int, endpoint: PixivEndpoints = Depends(request_client)):
     """
     ## Name: `illust`
 
@@ -75,7 +80,7 @@ async def illust(id: int, endpoint: PixivEndpoints = Depends(requestClient)):
 
 
 @router.get(EndpointsType.member)
-async def member(id: int, endpoint: PixivEndpoints = Depends(requestClient)):
+async def member(id: int, endpoint: PixivEndpoints = Depends(request_client)):
     """
     ## Name: `member`
 
@@ -98,7 +103,7 @@ async def member_illust(
     illust_type: IllustType = IllustType.illust,
     page: int = 1,
     size: int = 20,
-    endpoint: PixivEndpoints = Depends(requestClient),
+    endpoint: PixivEndpoints = Depends(request_client),
 ):
     """
     ## Name: `member_illust`
@@ -133,7 +138,7 @@ async def favorite(
     id: int,
     tag: Optional[str] = None,
     max_bookmark_id: Optional[int] = None,
-    endpoint: PixivEndpoints = Depends(requestClient),
+    endpoint: PixivEndpoints = Depends(request_client),
 ):
     """
     ## Name: `favorite`
@@ -164,7 +169,7 @@ async def following(
     id: int,
     page: int = 1,
     size: int = 20,
-    endpoint: PixivEndpoints = Depends(requestClient),
+    endpoint: PixivEndpoints = Depends(request_client),
 ):
     """
     ## Name: `following`
@@ -195,7 +200,7 @@ async def follower(
     id: int,
     page: int = 1,
     size: int = 20,
-    endpoint: PixivEndpoints = Depends(requestClient),
+    endpoint: PixivEndpoints = Depends(request_client),
 ):
     """
     ## Name: `following`
@@ -227,7 +232,7 @@ async def rank(
     date: Optional[RankingDate] = None,
     page: int = 1,
     size: int = 50,
-    endpoint: PixivEndpoints = Depends(requestClient),
+    endpoint: PixivEndpoints = Depends(request_client),
 ):
     """
     ## Name: `rank`
@@ -258,7 +263,7 @@ async def search(
     duration: Optional[SearchDurationType] = None,
     page: int = 1,
     size: int = 50,
-    endpoint: PixivEndpoints = Depends(requestClient),
+    endpoint: PixivEndpoints = Depends(request_client),
 ):
     """
     ## Name: `search`
@@ -293,7 +298,7 @@ async def search(
 
 
 @router.get(EndpointsType.tags)
-async def tags(endpoint: PixivEndpoints = Depends(requestClient)):
+async def tags(endpoint: PixivEndpoints = Depends(request_client)):
     """
     ## Name: `tags`
 
@@ -308,7 +313,7 @@ async def related(
     id: int,
     page: int = 1,
     size: int = 20,
-    endpoint: PixivEndpoints = Depends(requestClient),
+    endpoint: PixivEndpoints = Depends(request_client),
 ):
     """
     ## Name: `related`
@@ -335,7 +340,7 @@ async def related(
 
 
 @router.get(EndpointsType.ugoira_metadata)
-async def ugoira_metadata(id: int, endpoint: PixivEndpoints = Depends(requestClient)):
+async def ugoira_metadata(id: int, endpoint: PixivEndpoints = Depends(request_client)):
     """
     ## Name: `ugoira_metadata`
 
@@ -350,3 +355,139 @@ async def ugoira_metadata(id: int, endpoint: PixivEndpoints = Depends(requestCli
 
     """
     return await endpoint.ugoira_metadata(id=id)
+
+
+@router.get(EndpointsType.member_novel)
+async def member_novel(
+    id: int,
+    page: int = 1,
+    size: int = 20,
+    endpoint: PixivEndpoints = Depends(request_client),
+):
+    """
+    ## Name: `member_novel`
+
+    > 通过用户ID获取用户小说列表
+
+    ---
+
+    ### Required:
+
+    - ***int*** **`id`**
+        - Description: 用户ID
+
+    ---
+
+    ### Optional:
+    - ***int*** `page` = `1`
+        - Description: 页数
+    - ***int*** `size` = `20`
+        - Description: 每页大小
+    """
+
+    return await endpoint.member_novels(id=id, page=page, size=size)
+
+
+@router.get(EndpointsType.novel_series)
+async def novel_series(id: int, endpoint: PixivEndpoints = Depends(request_client)):
+    """
+    ## Name: `novel_series`
+
+    > 获取小说系列的信息
+
+    ---
+
+    ### Required:
+
+    - ***int*** **`id`**
+        - Description: 小说系列ID
+    """
+    return await endpoint.novel_series(id=id)
+
+
+@router.get(EndpointsType.novel_detail)
+async def novel_detail(id: int, endpoint: PixivEndpoints = Depends(request_client)):
+    """
+    ## Name: `novel_detail`
+
+    > 获取小说信息
+
+    ---
+
+    ### Required:
+
+    - ***int*** **`id`**
+        - Description: 小说ID
+    """
+    return await endpoint.novel_detail(id=id)
+
+
+@router.get(EndpointsType.novel_text)
+async def novel_text(id: int, endpoint: PixivEndpoints = Depends(request_client)):
+    """
+    ## Name: `novel_text`
+
+    > 获取小说正文
+
+    ---
+
+    ### Required:
+
+    - ***int*** **`id`**
+        - Description: 小说ID
+    """
+    return await endpoint.novel_text(id=id)
+
+
+@router.get(EndpointsType.search_novel)
+async def search_novel(
+    word: str,
+    mode: SearchNovelModeType = SearchNovelModeType.partial_match_for_tags,
+    sort: SearchSortType = SearchSortType.date_desc,
+    merge_plain_keyword_results: bool = True,
+    include_translated_tag_results: bool = True,
+    duration: Optional[SearchDurationType] = None,
+    page: int = 1,
+    size: int = 50,
+    endpoint: PixivEndpoints = Depends(request_client),
+):
+    """
+    ## Name: `search_novel`
+
+    > 搜索小说
+
+    ---
+
+    ### Required:
+
+    - ***str*** **`word`**
+        - Description: 关键词
+
+    ---
+
+    ### Optional:
+    - ***SearchNovelModeType*** `mode` = `SearchNovelModeType.partial_match_for_tags`
+        - Description: 搜索匹配方法
+    - ***SearchSortType*** `sort` = `SearchSortType.date_desc`
+        - Description: 结果排序方式
+    - ***bool*** `merge_plain_keyword_results` = `True`
+        - Description: 是否包含合并提供的关键字的搜索结果
+    - ***bool*** `include_translated_tag_results` = `True`
+        - Description: 是否包含其他语言标签的搜索结果
+    - ***Optional[SearchDurationType]*** `duration` = `None`
+        - Description: 小说发表的时间段
+    - ***int*** `page` = `1`
+        - Description: 页数
+    - ***int*** `size` = `50`
+        - Description: 每页大小
+    """
+    return await endpoint.search_novel(
+        word=word,
+        mode=mode,
+        sort=sort,
+        merge_plain_keyword_results=merge_plain_keyword_results,
+        include_translated_tag_results=include_translated_tag_results,
+        duration=duration,
+        page=page,
+        size=size,
+    )
